<div align="center">
	<h1>sUDP</h1>
</div> 

![PyPI - Version](https://img.shields.io/pypi/v/SUDP)
![PyPI - License](https://img.shields.io/pypi/l/sudp)
![PyPI - Format](https://img.shields.io/pypi/format/SUDP)
![sudp](https://raw.githubusercontent.com/artegoser/artegoser.github.io/master/imgsforproj/sudp.png "sudp")

Safely wrapper for UDP protocol. Python library.  

After sending the message, the sender waits for a response from the recipient (confirmation of delivery). If there is no response, the data was not delivered

<div><a href='https://ru.freepik.com/vectors/background'>Background author</a></div>
